#!/usr/bin/env python
#
# Copyright (c) 2004 Nokia
# Author: Timo Savola <tsavola@movial.fi>
#
# Licensed under GPL, see COPYING for details.
#

import os, sys, optparse

sys.path += [os.path.dirname(os.path.realpath(sys.argv[0])) + "/../lib/python2.3"]

from sb import config

def usage():
	print "Usage: sb-conf <ACTION> [<OPTIONS>]"
	print
	print "     ACTION  OPTIONS                  ACTION  OPTIONS"
	print "     ------  -------                  ------  -------"
	print
	print "      setup  [<TARGET>]                   st  [<TARGET>]"
	print "             [--compiler=<COMPILER>]          [-c <COMPILER>]"
	print "             [--devkits=<LIST>]               [-d <LIST]"
	print "             [--cputransp=<METHOD>]           [-t <METHOD]"
	print "             [--force]                        [-f]"
	print
	print "    install  [<TARGET>]                   in  [<TARGET>]"
	print "             [--clibrary]                     [-c]"
	print "             [--etc]                          [-e]"
	print "             [--devkits]                      [-d]"
	print "             [--fakeroot]                     [-F]"
	print "             [--gdb]                          [-G]"
	print "             [--strace]                       [-S]"
	print
	print "  rootstrap  [<TARGET>]                   rs  [<TARGET>]"
	print "             <FILE>|<URL>                     <FILE>|<URL>"
	print
	print "     select  [<TARGET>]                   se  [<TARGET>]"
	print
	print "      reset  [<TARGET>]                   re  [<TARGET>]"
	print "             [--force]                        [-f]"
	print
	print "     remove  [<TARGET>]                   rm  [<TARGET>]"
	print "             [--force]                        [-f]"
	print
	print "       show  [<TARGET>]                   sh  [<TARGET>]"
	print "             [--compiler]                     [-c]"
	print "             [--devkits]                      [-d]"
	print "             [--cputransp]                    [-t]"
	print
	print "       list  [--compilers]                ls  [-c]"
	print "             [--devkits]                      [-d]"
	print "             [--cputransps]                   [-t]"
	print "             [--targets]                      [-T]"
	print "             [--sessions]                     [-S]"
	print
	print "    current                               cu"
	print
	print "    version                               ve"
	print
	print "See 'sb-menu' for interactive versions of these actions."
	sys.exit(1)

class OptionParser (optparse.OptionParser):
	def print_usage(self, file = None):
		usage()

	def print_help(self, file = None):
		usage()

if len(sys.argv) < 2:
	usage()

action = sys.argv[1]
params = sys.argv[2:]

parser = OptionParser()

def parse():
	opts, args = parser.parse_args(params)
	if len(args) > 1:
		usage()
	if len(args) == 1:
		return args[0], opts
	return None, opts

def parse_target():
	if len(params) > 1:
		usage()
	elif len(params) == 1:
		return params[0]
	return None

try:
	if action == "setup" or action == "st":
		parser.add_option("-c", "--compiler")
		parser.add_option("-d", "--devkits")
		parser.add_option("-t", "--cputransp")
		parser.add_option("-f", "--force",    action="store_true")
		target, opts = parse()

		devkits = None
		if opts.devkits:
			devkits = []
			if opts.devkits != "none":
				devkits = opts.devkits.split(":")

		cputransp = None
		if opts.cputransp:
			cputransp = ""
			if opts.cputransp != "none":
				cputransp = opts.cputransp

		config.setup(target, opts.compiler, devkits, cputransp, opts.force)

	elif action == "install" or action == "in":
		parser.add_option("-c", "--clibrary", action="store_true")
		parser.add_option("-e", "--etc",      action="store_true")
		parser.add_option("-d", "--devkits",  action="store_true")
		parser.add_option("-F", "--fakeroot", action="store_true")
		parser.add_option("-G", "--gdb",      action="store_true")
		parser.add_option("-S", "--strace",   action="store_true")
		target, opts = parse()

		tools = []
		if opts.fakeroot:
			tools.append("fakeroot")
		if opts.gdb:
			tools.append("gdb")
		if opts.strace:
			tools.append("strace")

		config.install(target, opts.clibrary, opts.etc, opts.devkits, tools)

	elif action == "rootstrap" or action == "rs":
		if len(params) < 1 or len(params) > 2:
			usage()

		if len(params) == 2:
			target = params[0]
			rootstrap = params[1]
		else:
			target = None
			rootstrap = params[0]

		if rootstrap.find("://") >= 0:
			config.rootstrap(target, url=rootstrap)
		else:
			config.rootstrap(target, path=rootstrap)

	elif action == "select" or action == "se":
		config.select(parse_target())

	elif action == "reset" or action == "re":
		parser.add_option("-f", "--force", action="store_true")
		target, opts = parse()

		config.reset(target, opts.force)

	elif action == "remove" or action == "rm":
		parser.add_option("-f", "--force", action="store_true")
		target, opts = parse()

		config.remove(target, opts.force)

	elif action == "mount" or action == "mo":
		config.mount(parse_target())

	elif action == "umount" or action == "um":
		config.umount(parse_target())

	elif action == "show" or action == "sh":
		parser.add_option("-c", "--compiler",  action="store_true")
		parser.add_option("-d", "--devkits",   action="store_true")
		parser.add_option("-t", "--cputransp", action="store_true")
		target, opts = parse()

		all = not opts.compiler and not opts.devkits and not opts.cputransp

		compiler = config.get_compiler(target)
		if not compiler:
			if not target:
				target = config.current()
			raise config.Error("No such target: " + target)

		if opts.compiler or all:
			if all:
				print "Compiler:",
			print compiler

		if opts.devkits or all:
			devkit_list = config.get_devkits(target)
			if devkit_list:
				devkits = config.flatten(devkit_list, " ")
			else:
				devkits = "none"

			if all:
				print "Devkits:",
			print devkits

		if opts.cputransp or all:
			cputransp = config.get_cputransp(target)
			if not cputransp:
				cputransp = "none"

			if all:
				print "CPU-transparency:",
			print cputransp

	elif action == "list" or action == "ls":
		parser.add_option("-c", "--compilers",  action="store_true")
		parser.add_option("-d", "--devkits",    action="store_true")
		parser.add_option("-t", "--cputransps", action="store_true")
		parser.add_option("-T", "--targets",    action="store_true")
		parser.add_option("-S", "--sessions",   action="store_true")
		target, opts = parse()

		if opts.compilers:
			for name in config.list_compilers():
				print name

		if opts.devkits:
			for name in config.list_devkits():
				print name

		if opts.cputransps:
			for name in config.list_cputransps():
				print name

		if opts.targets:
			for name in config.list_targets():
				print name

		if opts.sessions:
			for name in config.list_sessions():
				print name

	elif action == "current" or action == "cu":
		print config.current()

	elif action == "version" or action == "ve":
		print config.version()

	else:
		usage()

except config.Error, e:
	sys.stderr.write("sb-conf: %s\n" % str(e))
	sys.exit(1)

